@@ -66,8 +66,8 @@ common use cases are described below.
 
     .. code-block:: sh
 
-        ordf -c development.ini -s --nocs \
-            -e 's@^http://.*bibliographica.org/@http://localhost:5000/@' \
+        ordf -c development.ini -s --nocs \\
+            -e 's@^http://.*bibliographica.org/@http://localhost:5000/@' \\
             http://bnb.bibliographica.org/entry/GB6214539
 
     It is possible to set these options in the configuration file as well like
