@@ -122,6 +122,8 @@ class ChangeContext(object):
         if embedded_changeset or cs:
             self.handler.put(self.store)
 
+        self.handler.commit()
+        
         return cs
 
     def rollback(self):
@@ -131,10 +133,22 @@ class ChangeContext(object):
         This simply emptying it of graphs that have been previously added using
         :meth:`add`.
         """
+        self.handler.rollback()
+        
         dummy = Graph("IOMemory")
         self.store = dummy.store
 
 
+class DummyTransaction(object):
+    def __enter__(self):
+        return self
+    def __exit__(self, *av, **kw):
+        pass
+    def commit(self):
+        pass
+    def rollback(self):
+        pass
+    
 class Handler(object):
     """
     Handle reading and writing of RDF Graphs
@@ -289,6 +303,14 @@ class Handler(object):
         for h in self.__readers__:
             h.remove(*av, **kw)
 
+    def commit(self, *av, **kw):
+        for h in self.__writers__:
+            h.commit()
+
+    def rollback(self, *av, **kw):
+        for h in self.__writers__:
+            h.rollback()
+            
     def context(self, user, reason):
         """
         Return an instance of :class:ChangeContext bound to this
@@ -363,12 +385,20 @@ class Handler(object):
         if hasattr(self, "fourstore"):
             return self.fourstore.query(q, initNs=namespaces)
         elif hasattr(self, "rdflib"):
-            prefixes = ["PREFIX %s: <%s>" % (k, namespaces[k]) for k in namespaces]
-            q = "\n".join(prefixes) + "\n" + q
+            #prefixes = ["PREFIX %s: <%s>" % (k, namespaces[k]) for k in namespaces]
+            #q = "\n".join(prefixes) + "\n" + q
             return self.rdflib.query(q)
+        elif hasattr(self, "surf"):
+            return self.surf.query(q)
         else:
             raise AttributeError("No SPARQL Implementations")
 
+    def transaction(self):
+        for h in self.__writers__:
+            if hasattr(h, "transaction"):
+                return h
+        return DummyTransaction()
+    
 class HandlerPlugin(object):
     """
     Instances of this class implement read and/or write operations on storage
@@ -468,6 +498,16 @@ class HandlerPlugin(object):
         Implement in concrete subclasses
         """
 
+    def commit(self):
+        """
+        Impement in concrete subclasses
+        """
+
+    def rollback(self):
+        """
+        Implement in concrete subclasses
+        """
+        
 class ConfigError(Exception):
     """
     Raised on configuration error
